"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TheiaTgQuickrunExtensionContribution = exports.MyTgEditorMenuContribution = exports.MyTgEditorCommandsContribution = void 0;
const core_1 = require("@theia/core");
const terminal_service_1 = require("@theia/terminal/lib/browser/base/terminal-service");
const inversify_1 = require("inversify");
const mavenInstallCommand = {
    id: 'install-maven-command',
    label: 'mvn clean install'
};
const gradleInstallCommand = {
    id: 'install-gradle-command',
    label: 'gradle build'
};
const nodeInstallCommand = {
    id: 'install-node-command',
    label: 'npm install'
};
const runMavenCommand = {
    id: 'run-maven-command',
    label: 'mvn spring-boot:run'
};
const runGradleCommand = {
    id: 'run-gradle-command',
    label: 'gradle bootRun'
};
const runNodeCommand = {
    id: 'run-node-command',
    label: 'npm start'
};
const stopApplicationCommand = {
    id: 'stop-app-command',
    label: 'Stop running application'
};
const djangoInstallDependencyCommand = {
    id: 'django-install-dependency-command',
    label: 'pip3 install -r requirements.txt'
};
const djangoRunCommand = {
    id: 'django-run-command',
    label: 'python3 manage.py runserver 0.0.0.0:9090'
};
const railsInstallDependencyCommand = {
    id: 'rails-install-dependency-command',
    label: 'bundle install'
};
const railsRunCommand = {
    id: 'rails-run-command',
    label: '/usr/local/bundle/bin/rails server -b 0.0.0.0 -p 9090'
};
const dotnetRunCommand = {
    id: 'dotnet-run-command',
    label: 'dotnet run --urls=http://0.0.0.0:9090/'
};
let MyTgEditorCommandsContribution = class MyTgEditorCommandsContribution {
    registerCommands(registry) {
        registry.registerCommand(mavenInstallCommand, {
            execute: async () => this.terminalService.newTerminal({
                title: "Install Dependency"
            }).then(terminalWidget => {
                terminalWidget.start().then(number => {
                    this.terminalService.open(terminalWidget);
                    terminalWidget.sendText('mvn clean install\n');
                });
            })
        });
        registry.registerCommand(gradleInstallCommand, {
            execute: async () => this.terminalService.newTerminal({
                title: "Install Dependency"
            }).then(terminalWidget => {
                terminalWidget.start().then(number => {
                    this.terminalService.open(terminalWidget);
                    terminalWidget.sendText("gradle build --build-cache -x test --parallel\n");
                });
            })
        });
        registry.registerCommand(nodeInstallCommand, {
            execute: async () => this.terminalService.newTerminal({
                title: "Install Dependency"
            }).then(terminalWidget => {
                terminalWidget.start().then(number => {
                    this.terminalService.open(terminalWidget);
                    terminalWidget.sendText('npm install\n');
                });
            })
        });
        registry.registerCommand(runMavenCommand, {
            execute: async () => this.terminalService.newTerminal({
                title: "Run Application"
            }).then(terminalWidget => {
                terminalWidget.start().then(number => {
                    this.terminalService.open(terminalWidget);
                    terminalWidget.sendText("fuser -k 9090/tcp\n");
                    terminalWidget.sendText("mvn spring-boot:run\n");
                });
            })
        });
        registry.registerCommand(runGradleCommand, {
            execute: async () => this.terminalService.newTerminal({
                title: "Run Application"
            }).then(terminalWidget => {
                terminalWidget.start().then(number => {
                    this.terminalService.open(terminalWidget);
                    terminalWidget.sendText("fuser -k 9090/tcp\n");
                    terminalWidget.sendText("gradle bootRun --parallel\n");
                });
            })
        });
        registry.registerCommand(runNodeCommand, {
            execute: async () => this.terminalService.newTerminal({
                title: "Run Application"
            }).then(terminalWidget => {
                terminalWidget.start().then(number => {
                    this.terminalService.open(terminalWidget);
                    terminalWidget.sendText("fuser -k 9090/tcp\n");
                    terminalWidget.sendText('npm start\n');
                });
            })
        });
        registry.registerCommand(stopApplicationCommand, {
            execute: async () => this.terminalService.newTerminal({
                title: "Stopping Application"
            }).then(terminalWidget => {
                terminalWidget.start().then(number => {
                    this.terminalService.open(terminalWidget);
                    terminalWidget.sendText("fuser -k 9090/tcp\n");
                });
            })
        });
        registry.registerCommand(djangoInstallDependencyCommand, {
            execute: async () => this.terminalService.newTerminal({
                title: "Install dependencies"
            }).then(terminalWidget => {
                terminalWidget.start().then(number => {
                    this.terminalService.open(terminalWidget);
                    terminalWidget.sendText("pip3 install -r requirements.txt\n");
                });
            })
        });
        registry.registerCommand(djangoRunCommand, {
            execute: async () => this.terminalService.newTerminal({
                title: "Run application"
            }).then(terminalWidget => {
                terminalWidget.start().then(number => {
                    this.terminalService.open(terminalWidget);
                    terminalWidget.sendText("python3 manage.py runserver 0.0.0.0:9090\n");
                });
            })
        });
        registry.registerCommand(railsInstallDependencyCommand, {
            execute: async () => this.terminalService.newTerminal({
                title: "Install dependencies"
            }).then(terminalWidget => {
                terminalWidget.start().then(number => {
                    this.terminalService.open(terminalWidget);
                    terminalWidget.sendText("bundle install\n");
                });
            })
        });
        registry.registerCommand(railsRunCommand, {
            execute: async () => this.terminalService.newTerminal({
                title: "Run application"
            }).then(terminalWidget => {
                terminalWidget.start().then(number => {
                    this.terminalService.open(terminalWidget);
                    terminalWidget.sendText("/usr/local/bundle/bin/rails server -b 0.0.0.0 -p 9090\n");
                });
            })
        });
        registry.registerCommand(dotnetRunCommand, {
            execute: async () => this.terminalService.newTerminal({
                title: "Run application"
            }).then(terminalWidget => {
                terminalWidget.start().then(number => {
                    this.terminalService.open(terminalWidget);
                    terminalWidget.sendText("dotnet run --urls=http://0.0.0.0:9090/\n");
                });
            })
        });
    }
};
__decorate([
    (0, inversify_1.inject)(terminal_service_1.TerminalService),
    __metadata("design:type", Object)
], MyTgEditorCommandsContribution.prototype, "terminalService", void 0);
MyTgEditorCommandsContribution = __decorate([
    (0, inversify_1.injectable)()
], MyTgEditorCommandsContribution);
exports.MyTgEditorCommandsContribution = MyTgEditorCommandsContribution;
const QUICK_RUN = [...core_1.MAIN_MENU_BAR, '6_quickrun'];
const SPRING_BOOT_QUICK_RUN = [...QUICK_RUN, 'spring_boot_6_quickrun'];
const REACT_QUICK_RUN = [...QUICK_RUN, 'react_6_quickrun'];
const ANGULAR_QUICK_RUN = [...QUICK_RUN, 'angular_6_quickrun'];
const DJANGO_QUICK_RUN = [...QUICK_RUN, 'django_6_quickrun'];
const RAILS_QUICK_RUN = [...QUICK_RUN, 'rails_6_quickrun'];
const DOTNET_QUICK_RUN = [...QUICK_RUN, 'dotnet_6_quickrun'];
let MyTgEditorMenuContribution = class MyTgEditorMenuContribution {
    registerMenus(menus) {
        menus.registerSubmenu(QUICK_RUN, 'Quick Run');
        menus.registerSubmenu(SPRING_BOOT_QUICK_RUN, 'Spring Boot', { order: '0' });
        menus.registerMenuAction(SPRING_BOOT_QUICK_RUN, {
            commandId: mavenInstallCommand.id,
            order: '0',
        });
        menus.registerMenuAction(SPRING_BOOT_QUICK_RUN, {
            commandId: gradleInstallCommand.id,
            order: '1',
        });
        menus.registerMenuAction(SPRING_BOOT_QUICK_RUN, {
            commandId: runMavenCommand.id,
            order: '2',
        });
        menus.registerMenuAction(SPRING_BOOT_QUICK_RUN, {
            commandId: runGradleCommand.id,
            order: '3',
        });
        menus.registerSubmenu(REACT_QUICK_RUN, 'React', { order: '1' });
        menus.registerMenuAction(REACT_QUICK_RUN, {
            commandId: nodeInstallCommand.id,
            order: '0',
        });
        menus.registerMenuAction(REACT_QUICK_RUN, {
            commandId: runNodeCommand.id,
            order: '1',
        });
        menus.registerSubmenu(ANGULAR_QUICK_RUN, 'Angular', { order: '2' });
        menus.registerMenuAction(ANGULAR_QUICK_RUN, {
            commandId: nodeInstallCommand.id,
            order: '0',
        });
        menus.registerMenuAction(ANGULAR_QUICK_RUN, {
            commandId: runNodeCommand.id,
            order: '1',
        });
        menus.registerSubmenu(DJANGO_QUICK_RUN, 'Django', { order: '3' });
        menus.registerMenuAction(DJANGO_QUICK_RUN, {
            commandId: djangoInstallDependencyCommand.id,
            order: '0'
        });
        menus.registerMenuAction(DJANGO_QUICK_RUN, {
            commandId: djangoRunCommand.id,
            order: '1'
        });
        menus.registerSubmenu(RAILS_QUICK_RUN, 'Rails', { order: '4' });
        menus.registerMenuAction(RAILS_QUICK_RUN, {
            commandId: railsInstallDependencyCommand.id,
            order: '0'
        });
        menus.registerMenuAction(RAILS_QUICK_RUN, {
            commandId: railsRunCommand.id,
            order: '1'
        });
        menus.registerSubmenu(DOTNET_QUICK_RUN, '.Net', { order: '5' });
        menus.registerMenuAction(DOTNET_QUICK_RUN, {
            commandId: dotnetRunCommand.id,
            order: '0'
        });
        menus.registerMenuAction(QUICK_RUN, {
            commandId: stopApplicationCommand.id,
            order: '6',
        });
    }
};
MyTgEditorMenuContribution = __decorate([
    (0, inversify_1.injectable)()
], MyTgEditorMenuContribution);
exports.MyTgEditorMenuContribution = MyTgEditorMenuContribution;
let TheiaTgQuickrunExtensionContribution = 
// Add contribution interface to be implemented, e.g. "TheiaTgQuickrunExtensionContribution implements CommandContribution"
class TheiaTgQuickrunExtensionContribution {
};
TheiaTgQuickrunExtensionContribution = __decorate([
    (0, inversify_1.injectable)()
    // Add contribution interface to be implemented, e.g. "TheiaTgQuickrunExtensionContribution implements CommandContribution"
], TheiaTgQuickrunExtensionContribution);
exports.TheiaTgQuickrunExtensionContribution = TheiaTgQuickrunExtensionContribution;
//# sourceMappingURL=theia-tg-quickrun-extension-contribution.js.map